### AUTHORS ###################################################################
# Name      Date
# Gareth    Tue Jul 28 13:45:14 2020
#

### DESCRIPTION ###############################################################
#  Analysis of depmap dependency data for CREBBP

### LIBRARIES #################################################################
library(plyr)

### MAIN ######################################################################

anaylsis.path <- "../../../../../../SHARED/analysis/ChrisLord/depmap_bimodality/"
data.path <- "../../../../../../SHARED/analysis/RachaelNatrajan/CREBBP_transcriptional_diversity/depmap/data/"
raw.path <- paste0(anaylsis.path, "data/raw_data/")

# depmap annotation # sample_info_v2.csv DepMap Public 20Q1
all.dep.ann <- read.csv(
  paste0(anaylsis.path, "data/raw_data/sample_infov2.csv"),
  header = T, 
  stringsAsFactors = FALSE,
  check.names = F,
  row.names = 1
);

# load depmap data
all.dep.datasets <- list()
all.dep.datasets[["Achilles_CRISPR"]] <- t(read.csv(
  paste0(raw.path, "Achilles_gene_effect.csv"), 
  header = T,
  stringsAsFactors = FALSE, 
  check.names = F,
  row.names = 1)
  );
colnames(all.dep.datasets[['Achilles_CRISPR']]) <- all.dep.ann[colnames(all.dep.datasets[['Achilles_CRISPR']]), "stripped_cell_line_name"]
rownames(all.dep.datasets[['Achilles_CRISPR']]) <- sapply(strsplit(rownames(all.dep.datasets[['Achilles_CRISPR']]), " " ), function(x) x[[1]])

all.dep.datasets[["D2_combined"]] <- read.csv(
  paste0(raw.path, "D2_combined_gene_dep_scores.csv"),
  header = T, 
  stringsAsFactors = FALSE,
  check.names = F,
  row.names = 1
  );
colnames(all.dep.datasets[["D2_combined"]]) <- sapply(strsplit(colnames(all.dep.datasets[["D2_combined"]]), "_"), function(x) x[[1]])
rownames(all.dep.datasets[['D2_combined']]) <- sapply(strsplit(rownames(all.dep.datasets[['D2_combined']]), " " ), function(x) x[[1]])

all.dep.datasets[["D2_Achilles"]] <- read.csv(
  paste0(raw.path, "D2_Achilles_gene_dep_scores.csv"),
  header = T, 
  stringsAsFactors = FALSE,
  check.names = F,
  row.names = 1
  );
colnames(all.dep.datasets[["D2_Achilles"]]) <- sapply(strsplit(colnames(all.dep.datasets[["D2_Achilles"]]), "_"), function(x) x[[1]])
rownames(all.dep.datasets[['D2_Achilles']]) <- sapply(strsplit(rownames(all.dep.datasets[['D2_Achilles']]), " " ), function(x) x[[1]])

# Load CCLE annoation 
CCLE.dat <- read.table(
  file = "../../../../../../SHARED/data/CCLE/processed/sample_annotation.txt",
  row.names = 1,
  header = T, 
  quote = "\"", 
  comment.char = "", 
  sep = "\t",
  stringsAsFactors = FALSE
  );

# remove the X from cell lines 
rownames(CCLE.dat) <- gsub("^X", "", rownames(CCLE.dat))
rownames(CCLE.dat) <- make.names(sapply(strsplit(rownames(CCLE.dat), "_"), function(x) x[[1]]), unique = T)

# select TNBC Cell Lines
CCLE.samples.BRCA  <- CCLE.dat[which(CCLE.dat$tcga.code == 'BRCA'),]
CCLE.samples.Basal  <- CCLE.samples.BRCA[CCLE.samples.BRCA$subtype.2 == "Basal-like",]
CCLE.samples.Basal <- CCLE.samples.Basal[!is.na(CCLE.samples.Basal$depMapID),]
CCLE.cell.lines.basal <- rownames(CCLE.samples.Basal)
CCLE.cell.lines.basal <- CCLE.cell.lines.basal[CCLE.cell.lines.basal != "JIMT1"]

# extract CREBBP dependency scores
feature.dep <- sapply(all.dep.datasets, function(x) x[which(rownames(x) == "CREBBP"), , drop = FALSE])
feature.dep.select <- lapply(1:length(feature.dep), function(x) as.data.frame(feature.dep[[x]][,match(CCLE.cell.lines.basal, colnames(feature.dep[[x]]), nomatch = 0), drop = F]))
feature.dep.merged <- rbind.fill(feature.dep.select)
rownames(feature.dep.merged) <- names(all.dep.datasets)

### MUT data ##################################################################
CCLE.mut.data <- read.csv(
  paste0(data.path, "CREBBP_mutations.csv"),
  header = TRUE, 
  stringsAsFactors = FALSE
);

CCLE.mut.data <- CCLE.mut.data[CCLE.mut.data$Cell.Line.Name %in% all.dep.ann$stripped_cell_line_name,]

### Drug data #################################################################
prism <- t(read.table(
  paste0(data.path, "primary-screen-replicate-collapsed-logfold-change.csv"), 
  header = T, 
  sep = ",", 
  stringsAsFactors = FALSE,
  row.names = 1
));

prism.cell.lines <- read.table(
  paste0(data.path, "primary-screen-cell-line-info.csv"), 
  header = TRUE, 
  sep = ",", 
  stringsAsFactors = FALSE
);

prism.treatment <- read.table(
  paste0(data.path, "primary-screen-replicate-treatment-info.csv"), 
  header = TRUE, 
  sep = ",", 
  stringsAsFactors = FALSE
);
prism.treatment <- prism.treatment[,c(1:10)]
prism.cell.lines <- prism.cell.lines[prism.cell.lines$depmap_id %in% rownames(all.dep.ann),]
prism.cell.lines$stripped_cell_line_name <- all.dep.ann[match(prism.cell.lines$depmap_id, rownames(all.dep.ann)), "stripped_cell_line_name"]

# remove columns not in cell line map
prism <- prism[ , colnames(prism) %in% prism.cell.lines$depmap_id]
prism <- prism[ , match(prism.cell.lines$depmap_id, colnames(prism)) ]
colnames(prism) <- prism.cell.lines[ match(colnames(prism), prism.cell.lines$depmap_id) , "stripped_cell_line_name"]

# sort out prism.treatment ids
prism.treatment$broad_id <- make.names(prism.treatment$broad_id)
rownames(prism) <- sapply(strsplit(rownames(prism), "\\.\\."), function(x) x[[1]])
prism <- prism[rownames(prism) %in%  prism.treatment$broad_id, ]
prism.treatment <- prism.treatment[match(rownames(prism), prism.treatment$broad_id),]

# merge mutation and prism data
prism.ccle.intersect <- intersect(colnames(prism), CCLE.mut.data$Cell.Line.Name)
feature.drug.merge <- data.frame(
  Cell.Line.Name = prism.ccle.intersect, 
  Drug = prism["BRD.K51313569.003.03.3",  match(prism.ccle.intersect, colnames(prism))],
  MUT.group = ifelse(CCLE.mut.data[match( prism.ccle.intersect, CCLE.mut.data$Cell.Line.Name),2] == 1, "MT", "WT")
  );

#########
# Plots # 
#########
plot.dir <- 'Plots/'
dir.create(plot.dir,showWarnings = F)
pdf(paste0(plot.dir, "palbociclib_vs_CREBBP_status.pdf"), width = 5, height = 5)
boxplot( feature.drug.merge$Drug ~ feature.drug.merge$MUT.group )
dev.off()

#########
# Stats # 
#########
cat('\n\n\n')
print("1. CREBBP mutational status vs Palbocicilib")
wilcox.test( feature.drug.merge$Drug ~ feature.drug.merge$MUT.group )

cat('\n\n\n')
print("2. CREBBP dependency scores")
print(feature.dep.merged)


